==> ruleset_checking_tool-0.1.0.tar.gz: ruleset_checking_tool-0.1.0/rct229/rulesets/ashrae9012019/ruleset_functions/baseline_systems/baseline_hvac_sub_functions/test_are_all_terminal_types_CAV.py <==
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_types_CAV import (
    are_all_terminal_types_cav,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_types_CAV_with_none_equal_to_null import (
    are_all_terminal_types_cav_with_none_equal_to_null,
)
from rct229.schema.validate import schema_validate_rmr

TEST_RMD = {
    "id": "test_rmd",
    "buildings": [
        {
            "id": "building_1",
            "building_segments": [
                {
                    "id": "building_segment_1",
                    "zones": [
                        {
                            "id": "zone 1",
                            "terminals": [
                                {"id": "terminal_1", "type": "CONSTANT_AIR_VOLUME"},
                                {"id": "terminal_2", "type": "VARIABLE_AIR_VOLUME"},
                                {"id": "terminal_3"},
                            ],
                        },
                    ],
                }
            ],
        }
    ],
    "type": "BASELINE_0",
}

TEST_RMD_FULL = {
    "id": "229_01",
    "ruleset_model_descriptions": [TEST_RMD],
    "data_timestamp": "2024-02-12T09:00Z",
}


def test__TEST_RMD__is_valid():
    schema_validation_result = schema_validate_rmr(TEST_RMD_FULL)
    assert schema_validation_result[
        "passed"
    ], f"Schema error: {schema_validation_result['error']}"


def test__all_terminal_type_CAV():
    assert are_all_terminal_types_cav(TEST_RMD, ["terminal_1"]) == True


def test__not_all_terminal_type_CAV():
    assert are_all_terminal_types_cav(TEST_RMD, ["terminal_2"]) == False


def test__none_terminal_type_CAV():
    assert are_all_terminal_types_cav(TEST_RMD, ["terminal_3"]) == True


def test__all_terminal_type_CAV_none_equal_null():
    assert (
        are_all_terminal_types_cav_with_none_equal_to_null(TEST_RMD, ["terminal_1"])
        == True
    )


def test__not_all_terminal_type_CAV_none_equal_null():
    assert (
        are_all_terminal_types_cav_with_none_equal_to_null(TEST_RMD, ["terminal_2"])
        == False
    )


def test__none_terminal_type_CAV_none_equal_null():
    assert (
        are_all_terminal_types_cav_with_none_equal_to_null(TEST_RMD, ["terminal_3"])
        == False
    )

==> ruleset_checking_tool-0.2.5.tar.gz: ruleset_checking_tool-0.2.5/rct229/rulesets/ashrae9012019/ruleset_functions/baseline_systems/baseline_hvac_sub_functions/test_are_all_terminal_types_CAV.py <==
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_types_CAV import (
    are_all_terminal_types_cav,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_types_CAV_with_none_equal_to_null import (
    are_all_terminal_types_cav_with_none_equal_to_null,
)
from rct229.schema.validate import schema_validate_rmd

TEST_RMD = {
    "id": "test_rmd",
    "buildings": [
        {
            "id": "building_1",
            "building_segments": [
                {
                    "id": "building_segment_1",
                    "zones": [
                        {
                            "id": "zone 1",
                            "terminals": [
                                {"id": "terminal_1", "type": "CONSTANT_AIR_VOLUME"},
                                {"id": "terminal_2", "type": "VARIABLE_AIR_VOLUME"},
                                {"id": "terminal_3"},
                            ],
                        },
                    ],
                }
            ],
        }
    ],
    "type": "BASELINE_0",
}

TEST_RMD_FULL = {
    "id": "229_01",
    "ruleset_model_descriptions": [TEST_RMD],
    "data_timestamp": "2024-02-12T09:00Z",
}


def test__TEST_RMD__is_valid():
    schema_validation_result = schema_validate_rmd(TEST_RMD_FULL)
    assert schema_validation_result[
        "passed"
    ], f"Schema error: {schema_validation_result['error']}"


def test__all_terminal_type_CAV():
    assert are_all_terminal_types_cav(TEST_RMD, ["terminal_1"]) == True


def test__not_all_terminal_type_CAV():
    assert are_all_terminal_types_cav(TEST_RMD, ["terminal_2"]) == False


def test__none_terminal_type_CAV():
    assert are_all_terminal_types_cav(TEST_RMD, ["terminal_3"]) == True


def test__all_terminal_type_CAV_none_equal_null():
    assert (
        are_all_terminal_types_cav_with_none_equal_to_null(TEST_RMD, ["terminal_1"])
        == True
    )


def test__not_all_terminal_type_CAV_none_equal_null():
    assert (
        are_all_terminal_types_cav_with_none_equal_to_null(TEST_RMD, ["terminal_2"])
        == False
    )


def test__none_terminal_type_CAV_none_equal_null():
    assert (
        are_all_terminal_types_cav_with_none_equal_to_null(TEST_RMD, ["terminal_3"])
        == False
    )
